#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-3NmfS4dDTwf3d9S6MNeUUt
key:                  tagstream-conduit-0.5.6-3NmfS4dDTwf3d9S6MNeUUt
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  32432eada6bb93122a8d0d2509e8ef75
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-3NmfS4dDTwf3d9S6MNeUUt
depends:
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx base-4.18.2.1
    blaze-builder-0.4.4.1-4hsr4c7kSq49yqSn7bkiqU bytestring-0.11.5.3
    case-insensitive-1.2.1.0-DkQB71KJg2v82iYJB6vXcb
    conduit-1.3.6.1-GX9q6BroOQ8DfdDkcg2QOw
    conduit-extra-1.3.8-DnALaIZUnFk6LCIAvzpD0b
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    resourcet-1.2.6-K6JBNnVEw7T4VmkwByHPd3 text-2.0.2
    transformers-0.6.1.0 xml-conduit-1.9.1.4-7yZcVOKFl6V2bsIGMa9wv8

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

